==> qtjambi-debuginfo-linux-x64-5.15.17.jar: sources/QtJambiWidgets/QTextBrowser_shell.h <==
#ifndef QTEXTBROWSER_SHELL_H
#define QTEXTBROWSER_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED

#include <qtwidgets-config.h>
#if QT_CONFIG(textbrowser)
#include <QtWidgets/qtextbrowser.h>
#endif //QT_CONFIG(textbrowser)
#include <QtJambi/QtJambiAPI>
#include <QTextEdit>
#include <QtCore/QList>
#include <QtCore/QStringList>
#include <QtCore/QVariant>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qlocale.h>
#include <QtCore/qmargins.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qmimedata.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qpoint.h>
#include <QtCore/qrect.h>
#include <QtCore/qregexp.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qsize.h>
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtCore/qurl.h>
#include <QtGui/qbackingstore.h>
#include <QtGui/qbitmap.h>
#include <QtGui/qcolor.h>
#include <QtGui/qcursor.h>
#include <QtGui/qevent.h>
#include <QtGui/qfont.h>
#include <QtGui/qfontinfo.h>
#include <QtGui/qfontmetrics.h>
#include <QtGui/qicon.h>
#include <QtGui/qkeysequence.h>
#include <QtGui/qpagedpaintdevice.h>
#include <QtGui/qpaintdevice.h>
#include <QtGui/qpaintengine.h>
#include <QtGui/qpainter.h>
#include <QtGui/qpalette.h>
#include <QtGui/qpixmap.h>
#include <QtGui/qregion.h>
#include <QtGui/qscreen.h>
#include <QtGui/qtextcursor.h>
#include <QtGui/qtextdocument.h>
#include <QtGui/qtextformat.h>
#include <QtGui/qtextoption.h>
#include <QtGui/qwindow.h>
#include <QtWidgets/qabstractscrollarea.h>
#include <QtWidgets/qaction.h>
#include <QtWidgets/qframe.h>
#if QT_CONFIG(graphicseffect)
#include <QtWidgets/qgraphicseffect.h>
#endif //QT_CONFIG(graphicseffect)
#if QT_CONFIG(graphicsview)
#include <QtWidgets/qgraphicsproxywidget.h>
#endif //QT_CONFIG(graphicsview)
#include <QtWidgets/qlayout.h>
#if QT_CONFIG(menu)
#include <QtWidgets/qmenu.h>
#endif //QT_CONFIG(menu)
#if QT_CONFIG(scrollbar)
#include <QtWidgets/qscrollbar.h>
#endif //QT_CONFIG(scrollbar)
#include <QtWidgets/qsizepolicy.h>
#include <QtWidgets/qstyle.h>
#include <QtWidgets/qstyleoption.h>
#if QT_CONFIG(textedit)
#include <QtWidgets/qtextedit.h>
#endif //QT_CONFIG(textedit)
#include <QtWidgets/qwidget.h>
#include <QtJambi/AboutToPaint>
#include <QtJambi/RegistryAPI>


#if QT_CONFIG(textbrowser)

class QTextBrowser_shell : public QTextBrowser, public QtJambiShellInterface
{
public:
    QTextBrowser_shell(QWidget* parent0 = nullptr);
    ~QTextBrowser_shell() override;

    void actionEvent(QActionEvent* event0) override;
    void backward() override;
    bool canInsertFromMimeData(const QMimeData* source0) const override;
    void changeEvent(QEvent* e0) override;
    void childEvent(QChildEvent* event0) override;
    void closeEvent(QCloseEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void contextMenuEvent(QContextMenuEvent* e0) override;
    QMimeData* createMimeDataFromSelection() const override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    void doSetTextCursor(const QTextCursor& cursor0) override;
    void dragEnterEvent(QDragEnterEvent* e0) override;
    void dragLeaveEvent(QDragLeaveEvent* e0) override;
    void dragMoveEvent(QDragMoveEvent* e0) override;
    void dropEvent(QDropEvent* e0) override;
    void enterEvent(QEvent* event0) override;
    bool event(QEvent* e0) override;
    bool eventFilter(QObject* arg__1, QEvent* arg__2) override;
    void focusInEvent(QFocusEvent* e0) override;
    bool focusNextPrevChild(bool next0) override;
    void focusOutEvent(QFocusEvent* ev0) override;
    void forward() override;
    bool hasHeightForWidth() const override;
    int heightForWidth(int arg__1) const override;
    void hideEvent(QHideEvent* event0) override;
    void home() override;
    void initPainter(QPainter* painter0) const override;
    void inputMethodEvent(QInputMethodEvent* arg__1) override;
    QVariant inputMethodQuery(Qt::InputMethodQuery property0) const override;
    void insertFromMimeData(const QMimeData* source0) override;
    void keyPressEvent(QKeyEvent* ev0) override;
    void keyReleaseEvent(QKeyEvent* e0) override;
    void leaveEvent(QEvent* event0) override;
    QVariant loadResource(int type0, const QUrl& name1) override;
    int metric(QPaintDevice::PaintDeviceMetric arg__1) const override;
    QSize minimumSizeHint() const override;
    void mouseDoubleClickEvent(QMouseEvent* e0) override;
    void mouseMoveEvent(QMouseEvent* ev0) override;
    void mousePressEvent(QMouseEvent* ev0) override;
    void mouseReleaseEvent(QMouseEvent* ev0) override;
    void moveEvent(QMoveEvent* event0) override;
    QPaintEngine* paintEngine() const override;
    void paintEvent(QPaintEvent* e0) override;
    QPaintDevice* redirected(QPoint* offset0) const override;
    void reload() override;
    void resizeEvent(QResizeEvent* e0) override;
    void scrollContentsBy(int dx0, int dy1) override;
    void setSource(const QUrl& name0) override;
    void setVisible(bool visible0) override;
    void setupViewport(QWidget* viewport0) override;
    QPainter* sharedPainter() const override;
    void showEvent(QShowEvent* arg__1) override;
    QSize sizeHint() const override;
    void tabletEvent(QTabletEvent* event0) override;
    void timerEvent(QTimerEvent* e0) override;
    bool viewportEvent(QEvent* arg__1) override;
    QSize viewportSizeHint() const override;
    void wheelEvent(QWheelEvent* e0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QTextBrowser_access : public QTextBrowser
{
    void __qt_doSetSource_cref_QUrl_QTextDocument_ResourceType(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID name0, jint type1);
    void __qt_backward(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    jboolean __qt_event_QEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID e0);
    jboolean __qt_focusNextPrevChild_bool(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jboolean next0);
    void __qt_focusOutEvent_QFocusEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID ev0);
    void __qt_forward(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    void __qt_home(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    void __qt_keyPressEvent_QKeyEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID ev0);
    jobject __qt_loadResource_int_cref_QUrl(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint type0, QtJambiNativeID name1);
    void __qt_mouseMoveEvent_QMouseEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID ev0);
    void __qt_mousePressEvent_QMouseEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID ev0);
    void __qt_mouseReleaseEvent_QMouseEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID ev0);
    void __qt_paintEvent_QPaintEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID e0);
    void __qt_reload(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    void __qt_setSource_cref_QUrl(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID name0);
};

#endif // QT_CONFIG(textbrowser)
#endif // QTEXTBROWSER_SHELL_H

==> qtjambi-debuginfo-linux-x64-6.5.7.jar: sources/QtJambiWidgets/QTextBrowser_shell.h <==
#ifndef QTEXTBROWSER_SHELL_H
#define QTEXTBROWSER_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <qtwidgets-config.h>
#if QT_CONFIG(textbrowser)
#include <QtWidgets/qtextbrowser.h>
#endif //QT_CONFIG(textbrowser)
#include <QtJambi/QtJambiAPI>
#include <QTextEdit>
#include <QtCore/QList>
#include <QtCore/QStringList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qlocale.h>
#include <QtCore/qmargins.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qmimedata.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qpoint.h>
#include <QtCore/qproperty.h>
#include <QtCore/qrect.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qsize.h>
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtCore/qurl.h>
#include <QtGui/qtguiglobal.h>
#if QT_CONFIG(action)
#include <QtGui/qaction.h>
#endif //QT_CONFIG(action)
#include <QtGui/qbackingstore.h>
#include <QtGui/qbitmap.h>
#include <QtGui/qcolor.h>
#include <QtGui/qcursor.h>
#include <QtGui/qevent.h>
#include <QtGui/qfont.h>
#include <QtGui/qfontinfo.h>
#include <QtGui/qfontmetrics.h>
#include <QtGui/qicon.h>
#if QT_CONFIG(shortcut)
#include <QtGui/qkeysequence.h>
#endif //QT_CONFIG(shortcut)
#include <QtGui/qpagedpaintdevice.h>
#include <QtGui/qpaintdevice.h>
#include <QtGui/qpaintengine.h>
#include <QtGui/qpainter.h>
#include <QtGui/qpalette.h>
#include <QtGui/qpixmap.h>
#include <QtGui/qregion.h>
#include <QtGui/qscreen.h>
#include <QtGui/qtextcursor.h>
#include <QtGui/qtextdocument.h>
#include <QtGui/qtextformat.h>
#include <QtGui/qtextoption.h>
#include <QtGui/qwindow.h>
#include <QtWidgets/qabstractscrollarea.h>
#include <QtWidgets/qframe.h>
#if QT_CONFIG(graphicseffect)
#include <QtWidgets/qgraphicseffect.h>
#endif //QT_CONFIG(graphicseffect)
#if QT_CONFIG(graphicsview)
#include <QtWidgets/qgraphicsproxywidget.h>
#endif //QT_CONFIG(graphicsview)
#include <QtWidgets/qlayout.h>
#if QT_CONFIG(menu)
#include <QtWidgets/qmenu.h>
#endif //QT_CONFIG(menu)
#if QT_CONFIG(scrollbar)
#include <QtWidgets/qscrollbar.h>
#endif //QT_CONFIG(scrollbar)
#include <QtWidgets/qsizepolicy.h>
#include <QtWidgets/qstyle.h>
#include <QtWidgets/qstyleoption.h>
#if QT_CONFIG(textedit)
#include <QtWidgets/qtextedit.h>
#endif //QT_CONFIG(textedit)
#include <QtWidgets/qwidget.h>
#include <QtJambi/AboutToPaint>
#include <QtJambi/RegistryAPI>


#if QT_CONFIG(textbrowser)

class QTextBrowser_shell : public QTextBrowser, public QtJambiShellInterface
{
public:
    QTextBrowser_shell(QWidget* parent0 = nullptr);
    ~QTextBrowser_shell() override;
    static void operator delete(void * ptr) noexcept;
private:
    QtJambiShell* __shell() const override final;
    friend class QTextBrowser_mshell;
    friend class QTextBrowser_oshell;
};


class QTextBrowser_mshell : public QTextBrowser_shell
{
public:
    using QTextBrowser_shell::QTextBrowser_shell;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
};


class QTextBrowser_oshell : public QTextBrowser_mshell
{
public:
    using QTextBrowser_mshell::QTextBrowser_mshell;
    ~QTextBrowser_oshell() override;
    void actionEvent(QActionEvent* event0) override;
    void backward() override;
    bool canInsertFromMimeData(const QMimeData* source0) const override;
    void changeEvent(QEvent* e0) override;
    void childEvent(QChildEvent* event0) override;
    void closeEvent(QCloseEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void contextMenuEvent(QContextMenuEvent* e0) override;
    QMimeData* createMimeDataFromSelection() const override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    void doSetSource(const QUrl& name0, QTextDocument::ResourceType type1) override;
    void doSetTextCursor(const QTextCursor& cursor0) override;
    void dragEnterEvent(QDragEnterEvent* e0) override;
    void dragLeaveEvent(QDragLeaveEvent* e0) override;
    void dragMoveEvent(QDragMoveEvent* e0) override;
    void dropEvent(QDropEvent* e0) override;
    void enterEvent(QEnterEvent* event0) override;
    bool event(QEvent* e0) override;
    bool eventFilter(QObject* arg__1, QEvent* arg__2) override;
    void focusInEvent(QFocusEvent* e0) override;
    bool focusNextPrevChild(bool next0) override;
    void focusOutEvent(QFocusEvent* ev0) override;
    void forward() override;
    bool hasHeightForWidth() const override;
    int heightForWidth(int arg__1) const override;
    void hideEvent(QHideEvent* event0) override;
    void home() override;
    void initPainter(QPainter* painter0) const override;
    void initStyleOption(QStyleOptionFrame* option0) const override;
    void inputMethodEvent(QInputMethodEvent* arg__1) override;
    QVariant inputMethodQuery(Qt::InputMethodQuery property0) const override;
    void insertFromMimeData(const QMimeData* source0) override;
    void keyPressEvent(QKeyEvent* ev0) override;
    void keyReleaseEvent(QKeyEvent* e0) override;
    void leaveEvent(QEvent* event0) override;
    QVariant loadResource(int type0, const QUrl& name1) override;
    int metric(QPaintDevice::PaintDeviceMetric arg__1) const override;
    QSize minimumSizeHint() const override;
    void mouseDoubleClickEvent(QMouseEvent* e0) override;
    void mouseMoveEvent(QMouseEvent* ev0) override;
    void mousePressEvent(QMouseEvent* ev0) override;
    void mouseReleaseEvent(QMouseEvent* ev0) override;
    void moveEvent(QMoveEvent* event0) override;
    QPaintEngine* paintEngine() const override;
    void paintEvent(QPaintEvent* e0) override;
    QPaintDevice* redirected(QPoint* offset0) const override;
    void reload() override;
    void resizeEvent(QResizeEvent* e0) override;
    void scrollContentsBy(int dx0, int dy1) override;
    void setVisible(bool visible0) override;
    void setupViewport(QWidget* viewport0) override;
    QPainter* sharedPainter() const override;
    void showEvent(QShowEvent* arg__1) override;
    QSize sizeHint() const override;
    void tabletEvent(QTabletEvent* event0) override;
    void timerEvent(QTimerEvent* e0) override;
    bool viewportEvent(QEvent* arg__1) override;
    QSize viewportSizeHint() const override;
    void wheelEvent(QWheelEvent* e0) override;
    static void operator delete(void * ptr) noexcept;
private:
    jmethodID __shell_javaMethod(int pos) const;
};

struct QTextBrowser_access : public QTextBrowser
{
    void __qt_backward(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    void __qt_doSetSource_cref_QUrl_QTextDocument_ResourceType(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID name0, jint type1);
    jboolean __qt_event_QEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID e0);
    jboolean __qt_focusNextPrevChild_bool(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jboolean next0);
    void __qt_focusOutEvent_QFocusEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID ev0);
    void __qt_forward(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    void __qt_home(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    void __qt_keyPressEvent_QKeyEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID ev0);
    jobject __qt_loadResource_int_cref_QUrl(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint type0, QtJambiNativeID name1);
    void __qt_mouseMoveEvent_QMouseEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID ev0);
    void __qt_mousePressEvent_QMouseEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID ev0);
    void __qt_mouseReleaseEvent_QMouseEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID ev0);
    void __qt_paintEvent_QPaintEvent_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID e0);
    void __qt_reload(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
};

#endif // QT_CONFIG(textbrowser)
#endif // QTEXTBROWSER_SHELL_H
